==> zio-aws-apigateway_3-5.17.126.2-sources.jar: zio/aws/apigateway/model/ImportDocumentationPartsRequest.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.apigateway.model.primitives.Blob
import scala.jdk.CollectionConverters.*
final case class ImportDocumentationPartsRequest(
    restApiId: String,
    mode: Option[zio.aws.apigateway.model.PutMode] = None,
    failOnWarnings: Option[Boolean] = None,
    body: Blob
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.ImportDocumentationPartsRequest = {
    import ImportDocumentationPartsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.ImportDocumentationPartsRequest
      .builder()
      .restApiId(restApiId: java.lang.String)
      .optionallyWith(mode.map(value => value.unwrap))(_.mode)
      .optionallyWith(failOnWarnings.map(value => value: java.lang.Boolean))(
        _.failOnWarnings
      )
      .body(
        software.amazon.awssdk.core.SdkBytes
          .fromByteArrayUnsafe(body.toArray[Byte])
      )
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.ImportDocumentationPartsRequest.ReadOnly =
    zio.aws.apigateway.model.ImportDocumentationPartsRequest
      .wrap(buildAwsValue())
}
object ImportDocumentationPartsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.ImportDocumentationPartsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.ImportDocumentationPartsRequest =
      zio.aws.apigateway.model.ImportDocumentationPartsRequest(
        restApiId,
        mode.map(value => value),
        failOnWarnings.map(value => value),
        body
      )
    def restApiId: String
    def mode: Option[zio.aws.apigateway.model.PutMode]
    def failOnWarnings: Option[Boolean]
    def body: Blob
    def getRestApiId: ZIO[Any, Nothing, String] = ZIO.succeed(restApiId)
    def getMode: ZIO[Any, AwsError, zio.aws.apigateway.model.PutMode] =
      AwsError.unwrapOptionField("mode", mode)
    def getFailOnWarnings: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("failOnWarnings", failOnWarnings)
    def getBody: ZIO[Any, Nothing, Blob] = ZIO.succeed(body)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.ImportDocumentationPartsRequest
  ) extends zio.aws.apigateway.model.ImportDocumentationPartsRequest.ReadOnly {
    override val restApiId: String = impl.restApiId(): String
    override val mode: Option[zio.aws.apigateway.model.PutMode] = scala
      .Option(impl.mode())
      .map(value => zio.aws.apigateway.model.PutMode.wrap(value))
    override val failOnWarnings: Option[Boolean] =
      scala.Option(impl.failOnWarnings()).map(value => value: Boolean)
    override val body: Blob = zio.aws.apigateway.model.primitives
      .Blob(zio.Chunk.fromArray(impl.body().asByteArrayUnsafe()))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.ImportDocumentationPartsRequest
  ): zio.aws.apigateway.model.ImportDocumentationPartsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigateway_3-5.17.166.1-sources.jar: zio/aws/apigateway/model/ImportDocumentationPartsRequest.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.apigateway.model.primitives.Blob
import scala.jdk.CollectionConverters.*
final case class ImportDocumentationPartsRequest(
    restApiId: String,
    mode: Optional[zio.aws.apigateway.model.PutMode] = Optional.Absent,
    failOnWarnings: Optional[Boolean] = Optional.Absent,
    body: Blob
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.ImportDocumentationPartsRequest = {
    import ImportDocumentationPartsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.ImportDocumentationPartsRequest
      .builder()
      .restApiId(restApiId: java.lang.String)
      .optionallyWith(mode.map(value => value.unwrap))(_.mode)
      .optionallyWith(failOnWarnings.map(value => value: java.lang.Boolean))(
        _.failOnWarnings
      )
      .body(
        software.amazon.awssdk.core.SdkBytes
          .fromByteArrayUnsafe(body.toArray[Byte])
      )
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.ImportDocumentationPartsRequest.ReadOnly =
    zio.aws.apigateway.model.ImportDocumentationPartsRequest
      .wrap(buildAwsValue())
}
object ImportDocumentationPartsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.ImportDocumentationPartsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.ImportDocumentationPartsRequest =
      zio.aws.apigateway.model.ImportDocumentationPartsRequest(
        restApiId,
        mode.map(value => value),
        failOnWarnings.map(value => value),
        body
      )
    def restApiId: String
    def mode: Optional[zio.aws.apigateway.model.PutMode]
    def failOnWarnings: Optional[Boolean]
    def body: Blob
    def getRestApiId: ZIO[Any, Nothing, String] = ZIO.succeed(restApiId)
    def getMode: ZIO[Any, AwsError, zio.aws.apigateway.model.PutMode] =
      AwsError.unwrapOptionField("mode", mode)
    def getFailOnWarnings: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("failOnWarnings", failOnWarnings)
    def getBody: ZIO[Any, Nothing, Blob] = ZIO.succeed(body)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.ImportDocumentationPartsRequest
  ) extends zio.aws.apigateway.model.ImportDocumentationPartsRequest.ReadOnly {
    override val restApiId: String = impl.restApiId(): String
    override val mode: Optional[zio.aws.apigateway.model.PutMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.mode())
        .map(value => zio.aws.apigateway.model.PutMode.wrap(value))
    override val failOnWarnings: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.failOnWarnings())
      .map(value => value: Boolean)
    override val body: Blob = zio.aws.apigateway.model.primitives
      .Blob(zio.Chunk.fromArray(impl.body().asByteArrayUnsafe()))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.ImportDocumentationPartsRequest
  ): zio.aws.apigateway.model.ImportDocumentationPartsRequest.ReadOnly =
    new Wrapper(impl)
}
